vmbx/vmbxengine/inc/mvmbxuiutilities.h
changeset 19 e44a8c097b15
parent 12 ae8abd0db65c
child 27 7eb70891911c
--- a/vmbx/vmbxengine/inc/mvmbxuiutilities.h	Mon May 03 13:01:45 2010 +0300
+++ b/vmbx/vmbxengine/inc/mvmbxuiutilities.h	Fri May 14 16:24:46 2010 +0300
@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
+* Copyright (c) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 * This component and the accompanying materials are made available
 * under the terms of "Eclipse Public License v1.0"
@@ -22,13 +22,13 @@
 
 // INCLUDES
 #include <cvoicemailbox.h>
+#include "voicemailboxdefsinternal.h"
 
 // CLASS DECLARATION
 
 /**
  *  MVmbxUiUtilities
  *
- *  @since S60 v5.2
  *  @lib vmbxengine.lib
  *
  */
@@ -39,7 +39,6 @@
     /**
      * Show mailbox query
      *
-     * @since S60 v5.2
      * @param in aType TVmbxType type
      * @param in aMode TVmbxQueryMode mode
      * @param out aNumber the voice mailbox number
@@ -52,7 +51,6 @@
      * Show mailbox query dialog
      * Leaves if user cancel selected.
      *
-     * @since S60 v5.2
      * @param aType in TVmbxType type
      * @param aMode Tin VmbxQueryMode mode
      * @param aNumber the voice mailbox number
@@ -62,41 +60,25 @@
         const TVmbxQueryMode & aMode, TDes& aNumber, TInt& aResult ) = 0;
 
     /**
-     * Show confirmation dialog when save number to phone
-     *
-     * @since S60 v5.2
-     */
-    virtual void ShowSaveToPhoneNote() = 0;
-
-    /**
-     * Show confirmation dialog when save number to SIM
+     * Show informationd note
      *
-     * @since S60 v5.2
+     * @param aType in TVmbxNoteType type
      */
-    virtual void ShowSaveToSimNote() = 0;
+    virtual void ShowInformationdNoteL(const TVmbxNoteType aType) = 0;
 
-    /**
-     * Show confirmation dialog when save video number
-     *
-     * @since S60 v5.2
-     */
-    virtual void ShowVideoSavedNote() = 0;
 
     /**
      * Show define number in selection dialog
-     * Leaves if user cancel selected.
      *
-     * @since S60 v5.2
      * @param in aType vmbx type
      * @param out aResult the result of dialog
      */
-    virtual void ShowDefineSelectionDialogL( TVmbxType& aType, TInt& aResult ) = 0;
+    virtual void ShowDefineSelectionDialog( TVmbxType& aType, TInt& aResult ) = 0;
 
     /**
      * Show call number in selection dialog
      * Leaves if user cancel selected.
      *
-     * @since S60 v5.2
      * @param in aArray array of the defined voice mailbox entry
      * @param in aIcons icons of the defined voice mailbox
      * @param out aParams the type TVoiceMailboxParams which should include
@@ -105,46 +87,33 @@
      */
     virtual void ShowCallSelectionDialogL( 
                 const RPointerArray<CVoiceMailboxEntry>& aArray, 
-               // CArrayPtr<CGulIcon>* aIcons,
                     TVoiceMailboxParams& aParams, TInt& aResult ) = 0;
 
     /**
      * Tries to close all open dialogs
      *
-     * @since S60 v5.2
      */
     virtual void DismissDialogL() = 0;
 
-    /**
-     * To get mailbox entry value
-     * Leaves with Symbian OS error code
-     *
-     * @since S60 v5.2
-     * @param aType TVmbxType type
-     */
-    virtual void ShowSaveEmptyNoteL( const TVmbxType& aType ) = 0;
 
     /**
      * Get Mailbox type default image.
      * If get unseccessful, Leaves with Symbian OS error code
      * 
-     * @since S60 v5.2
      * @param aParams Mailbox type for which image is needed.
      * @return aImage New image. Ownership is transferred.
      */
     //virtual CGulIcon* GetVmbxImageL( const TVoiceMailboxParams& aParams ) = 0;
 
     /**
      * Show error dialog
      *
-     * @since S60 v5.2
      */
-    virtual void ShowErrorDialogL() = 0;
+    virtual void ShowNotAllowedEditingDialogL() = 0;
 
     /**
      * Show Invalid Warning dialog.
      *
-     * @since S60 v5.2
      */
     virtual void ShowInvalidWarningDialogL() = 0;
     };
@@ -105,46 +87,33 @@
 
     /**
-     * Show error dialog
+     * Show not allowed editing dialog
      *